#
# spec file for package ghc-clash-lib
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%global pkg_name clash-lib
Name:           ghc-%{pkg_name}
Version:        0.99.2
Release:        1.2
Summary:        CAES Language for Synchronous Hardware - As a Library
License:        BSD-2-Clause
Group:          Development/Libraries/Haskell
URL:            https://hackage.haskell.org/package/%{pkg_name}
Source0:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/%{pkg_name}-%{version}.tar.gz
BuildRequires:  ghc-Cabal-devel
BuildRequires:  ghc-aeson-devel
BuildRequires:  ghc-ansi-wl-pprint-devel
BuildRequires:  ghc-attoparsec-devel
BuildRequires:  ghc-bytestring-devel
BuildRequires:  ghc-clash-prelude-devel
BuildRequires:  ghc-concurrent-supply-devel
BuildRequires:  ghc-containers-devel
BuildRequires:  ghc-data-binary-ieee754-devel
BuildRequires:  ghc-deepseq-devel
BuildRequires:  ghc-directory-devel
BuildRequires:  ghc-errors-devel
BuildRequires:  ghc-fgl-devel
BuildRequires:  ghc-filepath-devel
BuildRequires:  ghc-ghc-devel
BuildRequires:  ghc-hashable-devel
BuildRequires:  ghc-lens-devel
BuildRequires:  ghc-mtl-devel
BuildRequires:  ghc-parsers-devel
BuildRequires:  ghc-prettyprinter-devel
BuildRequires:  ghc-process-devel
BuildRequires:  ghc-reducers-devel
BuildRequires:  ghc-rpm-macros
BuildRequires:  ghc-template-haskell-devel
BuildRequires:  ghc-text-devel
BuildRequires:  ghc-time-devel
BuildRequires:  ghc-transformers-devel
BuildRequires:  ghc-trifecta-devel
BuildRequires:  ghc-unbound-generics-devel
BuildRequires:  ghc-unordered-containers-devel

%description
CλaSH (pronounced ‘clash’) is a functional hardware description language that
borrows both its syntax and semantics from the functional programming language
Haskell. The CλaSH compiler transforms these high-level descriptions to
low-level synthesizable VHDL, Verilog, or SystemVerilog.

Features of CλaSH:

* Strongly typed, but with a very high degree of type inference, enabling both
safe and fast prototyping using concise descriptions.

* Interactive REPL: load your designs in an interpreter and easily test all
your component without needing to setup a test bench.

* Higher-order functions, with type inference, result in designs that are fully
parametric by default.

* Synchronous sequential circuit design based on streams of values, called
'Signal's, lead to natural descriptions of feedback loops.

* Support for multiple clock domains, with type safe clock domain crossing.

This package provides:

* The CoreHW internal language: SystemF + Letrec + Case-decomposition

* The normalisation process that brings CoreHW in a normal form that can be
converted to a netlist

* Blackbox/Primitive Handling

Front-ends (for: parsing, typecheck, etc.) are provided by separate packages:

* <http://hackage.haskell.org/package/clash-ghc GHC/Haskell Frontend>

* <https://github.com/christiaanb/Idris-dev Idris Frontend>

Prelude library: <http://hackage.haskell.org/package/clash-prelude>.

%package devel
Summary:        Haskell %{pkg_name} library development files
Group:          Development/Libraries/Haskell
Requires:       %{name} = %{version}-%{release}
Requires:       ghc-compiler = %{ghc_version}
Requires(post): ghc-compiler = %{ghc_version}
Requires(postun): ghc-compiler = %{ghc_version}

%description devel
This package provides the Haskell %{pkg_name} library development files.

%prep
%setup -q -n %{pkg_name}-%{version}

%build
%ghc_lib_build

%install
%ghc_lib_install

%post devel
%ghc_pkg_recache

%postun devel
%ghc_pkg_recache

%files -f %{name}.files
%license LICENSE
%dir %{_datadir}/%{pkg_name}-%{version}
%dir %{_datadir}/%{pkg_name}-%{version}/prims
%dir %{_datadir}/%{pkg_name}-%{version}/prims/common
%dir %{_datadir}/%{pkg_name}-%{version}/prims/commonverilog
%dir %{_datadir}/%{pkg_name}-%{version}/prims/systemverilog
%dir %{_datadir}/%{pkg_name}-%{version}/prims/verilog
%dir %{_datadir}/%{pkg_name}-%{version}/prims/vhdl
%{_datadir}/%{pkg_name}-%{version}/prims/common/*.json
%{_datadir}/%{pkg_name}-%{version}/prims/commonverilog/*.json
%{_datadir}/%{pkg_name}-%{version}/prims/systemverilog/*.json
%{_datadir}/%{pkg_name}-%{version}/prims/verilog/*.json
%{_datadir}/%{pkg_name}-%{version}/prims/vhdl/*.json

%files devel -f %{name}-devel.files
%doc CHANGELOG.md README.md

%changelog
* Mon Jul  9 2018 psimons@suse.com
- Update clash-lib to version 0.99.2.
  [#] Changelog for the [`clash-lib`](http://hackage.haskell.org/package/clash-lib) package
  [#]# 0.99.1 *May 12th 2018*
  * Allow `~NAME[N]` tag inside `~GENSYM[X]`
* Thu Apr  5 2018 psimons@suse.com
- Update clash-lib to version 0.99.
  A more detailed change log is not available.
